## Repository regarding the thorondor package
This repository is the parent folder of the thorondor package, it contains the main program, meant to be imported via `pip install thorondor`.
There is also an example notebook in the example folder.

# Test and Example
A test of the program can be done on google colabs, by using the notebook in https://github.com/DSimonne/thorondor/tree/main/thorondor/Example

If you want to test on your own environment,, this notebook is automatically installed along with the package.

# Future work:
* Try to make a better use of voila packagen it works so far but not crazy, maybe just for plotting in big window
* Better import data tool
